==> ifrit_3.4.2.orig.tar.gz: ifrit-3.4.2/shells/qt/iqtshellsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IQTSHELLSUBJECT_H
#define IQTSHELLSUBJECT_H

//
//  A shell subject based on QT GUI interface
//
#include "ibgshellsubject.h"


class iqtShellSubject : public ibgShellSubject
{

	friend class iggSubjectFactory;

public:

	virtual ~iqtShellSubject();

protected:

	iqtShellSubject(iggShell *owner, int argc, char **argv);

	//
	//  System-level operations
	//
	virtual void GetDesktopDimensions(int &w, int &h) const;
	virtual void ProcessEvents(bool sync);
	virtual void CompleteStartUp();
	virtual void EnterEventLoop();
	virtual void Exit();

	//
	//  Shell capabilities
	//
	virtual bool CanRecognize8BitDisplay(bool check = false) const;
	virtual bool CanDockWindows() const;
	virtual bool CanChangeFontSize() const;

	virtual bool CheckCondition(int flag) const;

	//
	//  Workaround for that weird Qt bug
	//
	int qtargc;
	char **qtargv;
};

#endif  // IQTSHELLSUBJECT_H

==> ifrit_4.1.2.orig.tar.gz: ifrit-4.1.2/shells/qt/iqtshellsubject.h <==
/*=========================================================================

  Program:   Ionization FRont Interactive Tool (IFRIT)
  Language:  C++


Copyright (c) 2002-2012 Nick Gnedin 
All rights reserved.

This file may be distributed and/or modified under the terms of the
GNU General Public License version 2 as published by the Free Software
Foundation and appearing in the file LICENSE.GPL included in the
packaging of this file.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS ``AS IS''
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
ARE DISCLAIMED. IN NO EVENT SHALL THE AUTHORS OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=========================================================================*/


#ifndef IQTSHELLSUBJECT_H
#define IQTSHELLSUBJECT_H

//
//  A shell subject based on QT GUI interface
//
#include "ibgshellsubject.h"


class iqtShellSubject : public ibgShellSubject
{

	friend class iggSubjectFactory;

public:

	virtual ~iqtShellSubject();

protected:

	iqtShellSubject(iggShell *owner);

	//
	//  System-level operations
	//
	virtual void GetDesktopDimensions(int &w, int &h) const;
	virtual void ProcessEvents(bool sync);
	virtual void CompleteStartUp();
	virtual void EnterEventLoop();
	virtual void Exit();

	//
	//  User notification
	//
	virtual int PopupWindow(ibgWindowSubject *parent, const iString &text, int type, const char *button0, const char *button1, const char *button2) const;
};

#endif  // IQTSHELLSUBJECT_H
